@@ -23,11 +23,6 @@ Sample shortnames
    * - Sample shortname
      - Name of downloaded file
 """
-# download_sample_data is deprecated and not used here,
-# but during deprecation period want to keep it in this namespace
-# for backwards compatibility. noqa stops it being removed by
-# pre-commit as an unused import
-from ._sample import download_sample_data  # noqa
 from ._sample import _SAMPLE_DATA, _get_sample_files
 
 # Add a table row to the module docstring for each sample file
