@@ -6,6 +6,7 @@ from urllib.request import Request
 import numpy as np
 
 import astropy.io.fits
+from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.wcs import WCS
 
 from sunpy import log
@@ -22,7 +23,7 @@ from sunpy.util.datatype_factory_base import (
     NoMatchError,
     ValidationFunctionError,
 )
-from sunpy.util.exceptions import NoMapsInFileError, warn_user
+from sunpy.util.exceptions import NoMapsInFileError, SunpyDeprecationWarning, warn_user
 from sunpy.util.functools import seconddispatch
 from sunpy.util.io import is_url, parse_path, possibly_a_path
 from sunpy.util.metadata import MetaDict
@@ -97,7 +98,12 @@ class MapFactory(BasicRegistrationFactory):
         try:
             pairs = read_file(os.fspath(fname), **kwargs)
         except Exception as e:
-            raise OSError(f"Failed to read {fname}\n{e}") from e
+            msg = f"Failed to read {fname}\n{e}"
+            if kwargs.get("silence_errors") or kwargs.get("allow_errors"):
+                warn_user(msg)
+                return []
+            msg += "\n If you want to bypass these errors, pass `allow_errors=True`."
+            raise OSError(msg) from e
 
         new_pairs = []
         for pair in pairs:
@@ -125,7 +131,7 @@ class MapFactory(BasicRegistrationFactory):
         else:
             return False
 
-    def _parse_args(self, *args, silence_errors=False, **kwargs):
+    def _parse_args(self, *args, silence_errors=False, allow_errors=False, **kwargs):
         """
         Parses an args list into data-header pairs.
 
@@ -177,9 +183,9 @@ class MapFactory(BasicRegistrationFactory):
         data_header_pairs = []
         for arg in args:
             try:
-                data_header_pairs += self._parse_arg(arg, **kwargs)
+                data_header_pairs += self._parse_arg(arg, silence_errors=silence_errors, allow_errors=allow_errors,**kwargs)
             except NoMapsInFileError as e:
-                if not silence_errors:
+                if not (silence_errors or allow_errors):
                     raise
                 warn_user(f"One of the arguments failed to parse with error: {e}")
 
@@ -225,7 +231,8 @@ class MapFactory(BasicRegistrationFactory):
     def _parse_path(self, arg, **kwargs):
         return parse_path(arg, self._read_file, **kwargs)
 
-    def __call__(self, *args, composite=False, sequence=False, silence_errors=False, **kwargs):
+    @deprecated_renamed_argument("silence_errors","allow_errors","5.1", warning_type=SunpyDeprecationWarning)
+    def __call__(self, *args, composite=False, sequence=False, silence_errors=False, allow_errors=False, **kwargs):
         """ Method for running the factory. Takes arbitrary arguments and
         keyword arguments and passes them to a sequence of pre-registered types
         to determine which is the correct Map-type to build.
@@ -243,15 +250,20 @@ class MapFactory(BasicRegistrationFactory):
             Indicates if collection of maps should be returned as a `sunpy.map.MapSequence`.
             Default is `False`.
         silence_errors : `bool`, optional
+            Deprecated, renamed to `allow_errors`.
+
             If set, ignore data-header pairs which cause an exception.
             Default is ``False``.
+        allow_errors : `bool`, optional
+            If set, bypass data-header pairs or files which cause an exception and warn instead.
+            Defaults to `False`.
 
         Notes
         -----
         Extra keyword arguments are passed through to `sunpy.io.read_file` such
         as `memmap` for FITS files.
         """
-        data_header_pairs = self._parse_args(*args, silence_errors=silence_errors, **kwargs)
+        data_header_pairs = self._parse_args(*args, silence_errors=silence_errors, allow_errors=allow_errors, **kwargs)
         new_maps = list()
 
         # Loop over each registered type and check to see if WidgetType
@@ -268,7 +280,7 @@ class MapFactory(BasicRegistrationFactory):
                 new_maps.append(new_map)
             except (NoMatchError, MultipleMatchError,
                     ValidationFunctionError, MapMetaValidationError) as e:
-                if not silence_errors:
+                if not (silence_errors or allow_errors):
                     raise
                 warn_user(f"One of the data, header pairs failed to validate with: {e}")
 
