@@ -5,6 +5,7 @@ import re
 import tempfile
 import contextlib
 
+import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 import pytest
@@ -34,7 +35,6 @@ from sunpy.time import parse_time
 from sunpy.util import SunpyUserWarning
 from sunpy.util.exceptions import SunpyMetadataWarning
 from sunpy.util.metadata import ModifiedItem
-from sunpy.visualization.colormaps.cm import _get_mpl_cmap
 from .conftest import make_simple_map
 from .strategies import matrix_meta
 
@@ -278,7 +278,7 @@ def test_units(generic_map):
 
 
 def test_cmap(generic_map):
-    assert generic_map.cmap == _get_mpl_cmap('gray')
+    assert generic_map.cmap == matplotlib.colormaps['gray']
 
 
 def test_coordinate_frame(aia171_test_map):
@@ -296,6 +296,52 @@ def test_heliographic_longitude_crln(hmi_test_map):
                              rtol=1e-3)  # A tolerance is needed because L0 is for Earth, not SDO
 
 
+def test_observer_hgln_crln_priority():
+    """
+    When extracting the observer information from a FITS header, ensure
+    Stonyhurst (HG) coordinates are preferred over Carrington (CR) if present
+    (if not overridden by an instrument-specific `Map` subclass). Note that
+    `Map` creates a custom FITS header with a sanitized observer location, so
+    we also test a directly-instantiated `WCS` object in the coordinates
+    module.
+    """
+    data = np.ones([6, 6], dtype=np.float64)
+    header = {'CRVAL1': 0,
+              'CRVAL2': 0,
+              'CRPIX1': 5,
+              'CRPIX2': 5,
+              'CDELT1': 10,
+              'CDELT2': 10,
+              'CUNIT1': 'arcsec',
+              'CUNIT2': 'arcsec',
+              'PC1_1': 0,
+              'PC1_2': -1,
+              'PC2_1': 1,
+              'PC2_2': 0,
+              'NAXIS1': 6,
+              'NAXIS2': 6,
+              'CTYPE1': 'HPLN-TAN',
+              'CTYPE2': 'HPLT-TAN',
+              'date-obs': '1970-01-01T00:00:00',
+              'mjd-obs': 40587,
+              'hglt_obs': 0,
+              'hgln_obs': 0,
+              'crlt_obs': 2,
+              'crln_obs': 2,
+              'dsun_obs': 10,
+              'rsun_ref': 690000000}
+    generic_map = sunpy.map.Map((data, header))
+
+    c = generic_map.pixel_to_world(0*u.pix, 0*u.pix)
+    assert c.observer.lon == 0 * u.deg
+    # Note: don't test whether crlt or hglt is used---according to
+    # coordinates.wcs_utils._set_wcs_aux_obs_coord, those are expected to
+    # always be the same and so the same one is always used
+
+    c = generic_map.wcs.pixel_to_world(0, 0)
+    assert c.observer.lon == 0 * u.deg
+
+
 def test_remove_observers(aia171_test_map):
     aia171_test_map._remove_existing_observer_location()
     with pytest.warns(SunpyMetadataWarning,
@@ -1107,6 +1153,12 @@ def test_as_mpl_axes_aia171(aia171_test_map):
     assert all([ct1 == ct2 for ct1, ct2 in zip(ax.wcs.wcs.ctype, aia171_test_map.wcs.wcs.ctype)])
 
 
+def test_plot_with_norm_none(aia171_test_map):
+    # Confirm that norm == None does not raise an error, see https://github.com/sunpy/sunpy/pull/7261
+    ax = plt.subplot(projection=aia171_test_map)
+    aia171_test_map.plot(axes=ax, norm=None, vmin=0, vmax=0)
+
+
 def test_validate_meta(generic_map):
     """Check to see if_validate_meta displays an appropriate error"""
     with pytest.warns(SunpyMetadataWarning) as w:
@@ -1257,17 +1309,6 @@ def test_quicklook(mocker, aia171_test_map):
     assert aia171_test_map._repr_html_() in html_string
 
 
-def test_dask_array(generic_map):
-    dask_array = pytest.importorskip('dask.array')
-    da = dask_array.from_array(generic_map.data, chunks=(1, 1))
-    pair_map = sunpy.map.Map(da, generic_map.meta)
-
-    # Check that _repr_html_ functions for a dask array
-    html_dask_repr = pair_map._repr_html_(compute_dask=False)
-    html_computed_repr = pair_map._repr_html_(compute_dask=True)
-    assert html_dask_repr != html_computed_repr
-
-
 @pytest.fixture
 def generic_map2(generic_map):
     generic_map.meta["CTYPE1"] = "HPLN-TAN"
