@@ -19,7 +19,6 @@ from sunpy.map.maputils import (
     contains_limb,
     contains_solar_center,
     coordinate_is_on_solar_disk,
-    extract_along_coord,
     is_all_off_disk,
     is_all_on_disk,
     map_edges,
@@ -28,7 +27,6 @@ from sunpy.map.maputils import (
     sample_at_coords,
     solar_angular_radius,
 )
-from sunpy.util.exceptions import SunpyDeprecationWarning
 
 
 @pytest.fixture
@@ -219,6 +217,12 @@ def test_data_at_coordinates(aia171_test_map, aia_test_arc):
     assert_quantity_allclose(data[-1], intensity_along_arc[-1])
 
 
+def test_sample_out_of_bounds(aia171_test_map):
+    point = aia171_test_map.pixel_to_world([-1, 1]*u.pix, [-1, 1]*u.pix)
+    with pytest.raises(ValueError, match='At least one coordinate is not within the bounds of the map.'):
+        sample_at_coords(aia171_test_map, point)
+
+
 def test_contains_solar_center(aia171_test_map, all_off_disk_map, all_on_disk_map, straddles_limb_map, sub_smap):
     assert contains_solar_center(aia171_test_map)
     assert not contains_solar_center(all_off_disk_map)
@@ -277,38 +281,6 @@ def test_contains_coord(aia171_test_map):
     assert (contains_coordinate(smap, multi_coord) == [True, False]).all()
 
 
-def test_extract_along_coord(aia171_test_map):
-    nmax = max(*aia171_test_map.data.shape)
-    top_right = aia171_test_map.pixel_to_world((nmax-1)*u.pix, (nmax-1)*u.pix)
-    line = SkyCoord([aia171_test_map.bottom_left_coord, top_right])
-    with pytest.warns(SunpyDeprecationWarning):
-        intensity, line_discrete = extract_along_coord(aia171_test_map, line)
-    pix_diag = np.array([(i, i) for i in range(nmax)])
-    intensity_diag = u.Quantity(
-        [aia171_test_map.data[i[0], i[1]] for i in pix_diag],
-        aia171_test_map.unit
-    )
-    line_discrete_pix = aia171_test_map.world_to_pixel(line_discrete)
-    assert np.allclose(pix_diag[:, 0], line_discrete_pix.x.value)
-    assert np.allclose(pix_diag[:, 1], line_discrete_pix.y.value)
-    assert u.quantity.allclose(intensity_diag, intensity)
-
-
-@pytest.mark.filterwarnings("ignore:The extract_along_coord function is deprecated:sunpy.util.exceptions.SunpyDeprecationWarning")
-def test_extract_along_coord_one_point_exception(aia171_test_map):
-    with pytest.raises(ValueError, match='At least two points are required*'):
-        extract_along_coord(aia171_test_map, aia171_test_map.bottom_left_coord)
-    with pytest.raises(ValueError, match='At least two points are required*'):
-        extract_along_coord(aia171_test_map, SkyCoord([aia171_test_map.bottom_left_coord]))
-
-
-@pytest.mark.filterwarnings("ignore:The extract_along_coord function is deprecated:sunpy.util.exceptions.SunpyDeprecationWarning")
-def test_extract_along_coord_out_of_bounds_exception(aia171_test_map):
-    point = aia171_test_map.pixel_to_world([-1, 1]*u.pix, [-1, 1]*u.pix)
-    with pytest.raises(ValueError, match='At least one coordinate is not within the bounds of the map.*'):
-        extract_along_coord(aia171_test_map, point)
-
-
 @pytest.mark.parametrize(('x', 'y', 'sampled_x', 'sampled_y'),
                          [([1, 5], [1, 1], [1, 2, 3, 4, 5], [1, 1, 1, 1, 1]),
                           ([1, 5], [1, 2], [1, 2, 3, 3, 4, 5], [1, 1, 1, 2, 2, 2]),
