@@ -35,10 +35,11 @@ from ._attrs import (
     Time,
     Wavelength,
 )
+from .attr import AttrAnd, AttrOr
 
 # Trick the docs into thinking these attrs are defined in here.
-for _a in (Time, Instrument, Wavelength, Level, Sample, Detector, Resolution, Physobs, Source, Provider, ExtentType):
+for _a in (Time, Instrument, Wavelength, Level, Sample, Detector, Resolution, Physobs, Source, Provider, ExtentType, AttrAnd, AttrOr):
     _a.__module__ = __name__
 
 __all__ = ['Time', 'Instrument', 'Wavelength', 'Level', 'ExtentType',
-           'Sample', 'Detector', 'Resolution', 'Physobs', 'Source', 'Provider']
+           'Sample', 'Detector', 'Resolution', 'Physobs', 'Source', 'Provider', 'AttrAnd', 'AttrOr']
