@@ -6,4 +6,4 @@ from .chaincode import *
 from .hec import *
 from .parser import *
 
-__all__ = ['HECClient', 'HECResponse', 'Chaincode']
+__all__ = ['HECClient', 'HECResponse', 'Chaincode']  # noqa: F405
